@@ -26,7 +26,7 @@ print.fseq <- function(x, ...)
   flist <- functions(x)
 
   cat("Functional sequence with the following components:\n\n")
-  lapply(1:length(flist), 
+  lapply(seq_along(flist), 
       function(i) cat(" ", i, ". ", deparse(body(flist[[i]])), "\n", sep = ""))
   cat("\nUse 'functions' to extract the individual functions.", "\n")
   x
